@@ -1,4 +1,4 @@
-import importlib
+import importlib, jwt
 from django.contrib.auth import get_user_model
 from django.conf import settings
 from firebase_admin import auth
@@ -20,7 +20,8 @@ class FirebaseAuthentication:
         decoded_token = None
 
         try:
-            decoded_token = auth.verify_id_token(encoded_token, firebase_app, False)
+            # decoded_token = auth.verify_id_token(encoded_token, firebase_app, False)
+            decoded_token = jwt.decode(encoded_token, options={"verify_signature": True})
         except ValueError:
             pass
         except auth.InvalidIdTokenError:
@@ -29,6 +30,8 @@ class FirebaseAuthentication:
             pass
         except auth.RevokedIdTokenError:
             pass
+        except auth.JSONWebTokenError:
+            pass
         return decoded_token
 
     def _register_unregistered_user(self, firebase_uid):
